/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cocoon.portal.event;

import org.apache.avalon.framework.component.Component;

/**
 * Convert events from and into strings
 *
 * @author <a href="mailto:cziegeler@s-und-n.de">Carsten Ziegeler</a>
 * @author <a href="mailto:volker.schmitt@basf-it-services.com">Volker Schmitt</a>
 * 
 * @version CVS $Id: EventConverter.java 433543 2006-08-22 06:22:54Z crossley $
 */
public interface EventConverter extends Component {

    String ROLE = EventConverter.class.getName();
    
    /**
     * Encode an event.
     * This is used to "activate" events using a link
     * @param event The event to encode
     * @return A unique string representation for this event
     */
    String encode(Event event);
    
    /**
     * Decode an event
     * This is used to "activate" events using a link
     * @param value The string representation created using {@link #encode(Event)}
     * @return The event or null 
     */
    Event decode(String value);

    /**
     * This notifies the converter that a new event processing phase starts
     */
    void start();
    
    /**
     * This notifies the converter that an event processing phase ends
     */
    void finish();

    /**
     * Returns true if events are not to be returned as request parameters
     */
    boolean isMarshallEvents();
}
